PatternBody

Struct PatternBody 

pub struct PatternBody {
    pub stages: Vec<StageAst>,
    pub negations: Vec<NegationAst>,
    pub temporals: Vec<TemporalAst>,
    pub metadata: Vec<(String, String)>,
    pub deadline: Option<f64>,
    pub unordered_groups: Vec<Vec<usize>>,
    pub private: bool,
}
The interior of a pattern — stages, negations, and temporal constraints, without the pattern name { } wrapper.

Used by crate::parser::Parser::parse_pattern_body() for composable parsing — downstream DSLs can parse a pattern body embedded in their own block syntax.

Fields

stages: Vec<StageAst>negations: Vec<NegationAst>temporals: Vec<TemporalAst>metadata: Vec<(String, String)>deadline: Option<f64>unordered_groups: Vec<Vec<usize>>private: bool