pub struct ParsedDocument<L = String, V = MemValue> {
pub patterns: Vec<Pattern<L, V>>,
pub graphs: Vec<MemGraph>,
}Expand description
Result of parsing a document with patterns, graphs, and compose directives.
Generic over label and value types with defaults for backward compatibility.
Use ParsedDocument (no params) for the default Pattern<String, MemValue>.
Fields
patterns: Vec<Pattern<L, V>>All compiled patterns (both directly declared and composed).
graphs: Vec<MemGraph>Parsed graphs (always MemGraph — graphs are test-only).